#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Date    : 2019-05-24 14:48:20
# @Author  : Blackstone
# @to      :


def get_connect_config(config_path=None,**configoptions):
	pass



get_connect_config("aa",aa=1)